/*
 * Program:    AssertionContext.java
 * Purpose:    Interface file for Assertion Builder
 * @author     Ray Lai (ray.lai@sun.com)
 * @version    1.0
 * Updated:    April 17, 2005, 2:19 PM
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 * =====================================================================================
 */

package com.csp.identity;

import org.w3c.dom.Document;


public interface AssertionContext {
    
    /** set assertion type
     *
     *  @param String assertion type, e.g. authentication, attribute
     **/    
    public void setAssertionType(String assertionType);

    /** create SSO token
     *
     *  @param Object security token
     **/
    public void createSSOToken(Object securityToken);

    /** check for valid SAML statement
     *
     *  @return boolean true/falase
     **/
    public boolean isValidStatement();
   
    /** set authentication method
     *
     *  @param String authentication method
     **/
    public void setAuthenticationMethod(String authMethod);
    
    /** get authentication method
     *
     *  @return String authentication method
     **/
    public String getAuthenticationMethod();
   
    /** create SAML assertion statement
     *  
     *  Note - the @return has not been implemented.
     *
     *  @return Document xml document
     **/
    public Document createAssertionStatement(Object assertObject);
    
    /** get SAML assertion statement
     *
     *  @return Document xml document
     **/
    public Document getAssertionStatement();
    
    /** remove assertion statement
     *
     **/
    public void removeAssertionStatement();
    
    /** create assertion reply
     *
     * @return Document xml document
     **/
    public Document createAssertionReply(Object assertionRequest);
    
    /** get assertion reply
     *
     * @return Document xml document
     **/
    public Document getAssertionReply();
    
    /** remove assertion reply
     *
     **/
    public void removeAssertionReply();
    
    /** set protocol binding
     *
     * @param String protocol binding
     **/
    public void setProtocolBinding (String protocolBinding);
    
    /** get protocol binding
     *
     * @return String protocol binding
     **/
    public String getProtocolBinding();
}