/*
 * Program:    SSODelegatorFactory.java
 * Purpose:    Interface file for SSODelegatorFactory
 * @author     Ray Lai (ray.lai@sun.com)
 * @version    1.0
 * Updated:    April 19, 2005, 11:04 AM
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 * =====================================================================================
 */

package com.csp.identity;

public interface SSODelegatorFactory {
    
    /**
     * Create a SSO connection with the remote service provider
     * Need to pass a security token and the target service name.
     * The service locator will look up where the service name is.
     * And then invoke the remote object class/URI based on the 
     * protocol binding.
     *
     * @param Object security token (for example, you can re-use Credential Tokenizer)
     * @param String service name for the remote service provider
     */
    public void createSSOConnection(Object securityToken, String serviceName) 
        throws com.csp.identity.SSODelegatorException;
    
   /**
     * Close a SSO connection with the remote service provider
     * Need to pass a security token and the target service name.
     * The service locator will look up where the service name is.
     * And then invoke the remote object class/URI based on the 
     * protocol binding.
     *
     * @param Object security token (for example, you can re-use Credential Tokenizer)
     * @param String service name for the remote service provider
     */    
    public void closeSSOConnection(Object securityToken, String serviceName)
        throws com.csp.identity.SSODelegatorException;

    /**
     * Get status from the remote service provicer.
     * Need to pass a security token and the target service name.
     * The service locator will look up where the service name is.
     * And then invoke the remote object class/URI based on the 
     * protocol binding.
     *
     * @param Object security token (for example, you can re-use Credential Tokenizer)
     * @param String service name for the remote service provider
     */
    public String getServiceStatus(Object securityToken, String serviceName)
        throws com.csp.identity.SSODelegatorException;
}
