/*
 * Program:    SSOServiceProvider.java
 * Purpose:    Interface file for managing SSO service provider
 * @author     Ray Lai (ray.lai@sun.com)
 * @version    1.0
 * Updated:    April 19 2005
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 * ===================================================================================== 
 */

package com.csp.identity;

import com.csp.identity.*;

public interface SSOServiceProvider  {
    
    /**
     * Create and initialize remote security service.
     * Need to pass the SSO context which contains private configuration information.
     * Here this assumes that your SSODelegatorFactory implementation has already
     * verified the security token or performed necessary authentication/authorization.
     *
     * @param SSOContext context that contains private config or session info
     */
    public void createService(com.csp.identity.SSOContext context);
    
    /**
     * Close remote security service.
     * Here this assumes that your SSODelegatorFactory implementation has already
     * verified the security token or performed necessary authentication/authorization.
     */    
    public void closeService();

    /**
     * Reconnect to remote security service.
     * Here this assumes that your SSODelegatorFactory implementation has already
     * verified the security token or performed necessary authentication/authorization.
     */    
    public Object reconnect();
    
}
