/*
 * Program:    X509CertToken.java
 * Purpose:    Class object for encapsulating X.509v3 certificate as security token
 * @author     Ray Lai (ray.lai@sun.com)
 * @version    1.1
 * Updated:    April 16, 2005
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 * =====================================================================================
 */

package com.csp.identity;

import java.math.BigInteger;

public class X509CertToken extends com.csp.identity.SecurityToken {
    
    protected java.security.cert.X509Certificate  x509cert;
    static final String                           TOKEN_TYPE = "X509CERT_TOKEN";

    /** Constructor - create X509CertToken 
     *
     *  In future implementation, the constructor should be private, and this class
     *  should provide a getInstance() to fetch the instance.
     */
    public X509CertToken(String principal, 
            java.security.cert.X509Certificate x509cert,
            String crypto) {
        
        // Crypto is a temp class; Set to null when creating the constructor.
        // In future, this can be Apache Merlin's Crypto type
        this.principal = principal;
        this.x509cert = x509cert;
    }
    /**
     * Get token id from the binary token
     *
     * @return binaryToken security token in binary form
     */
    public java.security.cert.X509Certificate getToken() {
        return this.x509cert;
    }
    
    public String getIssueDN() {
        return this.x509cert.getIssuerDN().toString();
    }

    public String getSubjectDN() {
        return this.x509cert.getSubjectDN().toString();
    }

    public BigInteger getSerialNumber() {
        return this.x509cert.getSerialNumber();
    }
    
    public int getVersion() {
        return this.x509cert.getVersion();
    }
}
