/*
 * Program: PasswordSyncManager.java
 * Purpose: Read pstdMapping.xml config file, issue SPML request to start password synchronization
 * @author: Ray Lai (ray.lai@sun.com)
 * Updated: May 31, 2005, 4:24 PM
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 * ============================================================================================
 * Instructions:
 * 1. Start your local JMS server (e.g. imqbrokerd from Sun Java System Application Server)
 * 2. Invoke your consumers
 */

package com.csp.provisioning;

import java.util.Date;
import java.util.LinkedHashMap;


public class PasswordSyncManager {
    
    protected ProvisioningUserProfile userProfile = null;
    protected String protocolBinding;
    protected String topicName;
    protected String fullName;
    protected String firstName;
    protected String lastName;
    protected String emailAddress;
    protected String userId;
    protected String password;    
    protected ServiceConfig serviceConfig;
    protected ServiceConfigContext context;
    protected LinkedHashMap<String,ServiceConfigContext> serviceConfigHashMap = new LinkedHashMap();
    protected String timeStamp;
    
    
    /**
     * Creates a new instance of PasswordSyncManager 
     */
    public PasswordSyncManager() {
        setupDefaultUserProfile();
        this.serviceConfig = new ServiceConfig();
        this.serviceConfigHashMap = serviceConfig.getAllConfigContext();
        System.out.println("Password synchronization requests start.");
        processPwdSyncRequests();
        System.out.println("Password synchronization requests completed.");
    }
    
    /**
     * set up default user profile for the password sync requests
     *
     */
    private void setupDefaultUserProfile() {
        // set up default user profile
        String fullName = "Mary Jo Parker";
        String firstName = "Mary Jo";
        String lastName = "Parker";
        String userId = "mjparker";
        String emailAddress = "mjparker@namredips.com";
        String password = "secret";     
        this.userProfile = new ProvisioningUserProfile(fullName, firstName, lastName, userId,
            emailAddress, password);
    }
    
    /**
     * process password sync requests
     *
     */
    private void processPwdSyncRequests() {
        this.timeStamp = new Date().toString();
        
        for(ServiceConfigContext configContext: this.serviceConfigHashMap.values()) {      
            this.topicName = configContext.getTopicName();
            this.protocolBinding = configContext.getProtocolBinding();
            System.out.println(this.timeStamp + "- " + configContext.getApplicationId() + " is being processed under " + this.topicName + " using " + this.protocolBinding);
            new PasswordSyncRequest(this.userProfile, this.topicName, this.protocolBinding);
        }        
    }
    
    public static void main(String args[]) {
        new PasswordSyncManager();
    }
}
