 /*
 * Program: ProvisioningUserProfile.java
 * Purpose: To encapsulate user profile for the purpose of provisioning a user account
 *          in the provisioning target systems.
 * @author: Ray Lai (ray.lai@sun.com)
 * Updated: May 28, 2005, 5:32 PM
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 * ============================================================================================
 * Remark:
 *
 *   This ProvisioningUserProfile can extend the SecurityToken class from the Credential 
 * Tokenizer pattern.  If you extend the SecurityToken class, you can make use of the 
 * Credential Tokenizer to encapsulate security tokens such as X.509v3 or biometrics binary tokens.
 *
 * ============================================================================================
 */

package com.csp.provisioning;


public class ProvisioningUserProfile {
    
    protected String fullName;
    protected String firstName;
    protected String lastName;
    protected String userId;
    protected String emailAddress;
    protected String password;  // not used in this example
    
    /** Constructor - Creates a new instance of ProvisioningUserProfile */
    public ProvisioningUserProfile(String fullName, String firstName, String lastName, String userId,
            String emailAddress, String password) {
        this.fullName = fullName;
        this.firstName = firstName;
        this.lastName = lastName;
        this.userId = userId;
        this.emailAddress = emailAddress;
        this.password = password;
    }
 
    /**
     * Get full name
     *
     * @return String fullName
     */
    public String getFullName() {
        return this.fullName;
    }    
    
    /**
     * Get first name
     *
     * @return String firstName
     */
    public String getFirstName() {
        return this.firstName;
    }    
    
        /**
     * Get last name
     *
     * @return String lastName
     */
    public String getLastName() {
        return this.lastName;
    }    
    
    
    /**
     * Get user id
     *
     * @return String userId
     */
    public String getUserId() {
        return this.userId;
    }    
    
    
    /**
     * Get email address
     *
     * @return String emailAddress
     */
    public String getEmailAddress() {
        return this.emailAddress;
    }    
    
    /**
     * Get token id from the binary token
     *
     * @return binaryToken security token in binary form
     */
    public String getToken() {
        return this.password;
    }    
}
