/*
 * Program: TakeAction.java
 * Purpose: implementation for action taken by PasswordSyncListener
 * @author: Ray Lai (ray.lai@sun.com)
 * Updated: May 31, 2005, 9:39 AM
 * Copyright:  (c) 2006 by Ray Lai
 * Remarks:    Full program and documentation will be available under developer.java.net
 *             For simplicity, logger class is removed.
 * ============================================================================================
 */

package com.csp.provisioning;

import javax.jms.JMSException;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.jms.Topic;
import javax.jms.TopicConnection;
import javax.jms.TopicConnectionFactory;
import javax.jms.TopicPublisher;
import javax.jms.TopicSession;


public class TakeAction {
    protected TopicConnectionFactory  topicConnectionFactory = null;
    protected TopicConnection         topicConnection = null;
    protected TopicSession            topicSession = null;
    protected Topic                   topic = null;
    protected String                  topicName = null;
      
    
    /** Constructor - Creates a new instance of TakeAction */
    public TakeAction() {
    }
    
    /*
     * Set up the JMS topic connection
     *
     * @param String topicName String JMS topic name
     * @exception Exception ex 
     */
    public  void init(String topicName) {
        
        try {
            this.topicConnectionFactory = new com.sun.messaging.TopicConnectionFactory();
            this.topicConnection = this.topicConnectionFactory.createTopicConnection();
            this.topicSession = this.topicConnection.createTopicSession(false, Session.AUTO_ACKNOWLEDGE);
            this.topic = this.topicSession.createTopic(topicName);
            
        } // try
        catch (Exception ex) {
            ex.printStackTrace();
            System.out.println("Cannot create topics or topic names");
            System.out.println("Connection problem: " + ex.toString());
            if (this.topicConnection != null) {
                try {
                    this.topicConnection.close();
                } catch (JMSException moreEx) {
                    moreEx.printStackTrace();
                }
                System.exit(1);
            } // if topicConnection
        } // catch
    }  // init
    
   /*
    * Publish successfully completed application
    *    list to a pre-defined topic.
    *    The structure of the message is simply <application>
    *
    * @param String application application name where password is synch
    * @param String protocol either SOAP or JMS
    * @exception JMSException ex 
    */
    public void publishPwdSyncResult(String application, String protocol) {
        
        TextMessage    sentMessage = null;
        TopicPublisher topicPublisher =  null;
        
        try {
            topicPublisher = this.topicSession.createPublisher(topic);
            sentMessage = this.topicSession.createTextMessage();
            sentMessage.setText(application);
            
            topicPublisher.publish(sentMessage);
        } // try
        catch (JMSException jmsex) {
            jmsex.printStackTrace();
            System.out.println("Cannot publish SOAP message");
            System.out.println("Exception occurred: " + jmsex.toString());
        } // catch
        finally {
            if (topicConnection != null) {
                try {
                    this.topicConnection.close();
                } catch (JMSException jmsex) {
                    jmsex.printStackTrace();
                    System.out.println("Cannot close topicConnection");
                    System.out.println("Connection problem: " + jmsex.toString());
                } // catch
            } // if topicConnection
        } // finally
    }
    
    
    
}
